===============================
spip
===============================


.. image:: https://img.shields.io/pypi/v/spip.svg
        :target: https://pypi.python.org/pypi/spip

.. image:: https://readthedocs.org/projects/spip/badge/?version=latest
        :target: https://spip.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/florianludwig/spip/shield.svg
     :target: https://pyup.io/repos/github/florianludwig/spip/
     :alt: Updates

.. image:: https://gitlab.com/f-ludwig/spip/badges/master/build.svg
     :target: https://gitlab.com/f-ludwig/spip/commits/master)
     :alt: gitlab CI


pip <3 dnf/apt-get


.. image:: https://asciinema.org/a/5xrxo8azct86r0h6abbil8mec.png
   :target: https://asciinema.org/a/5xrxo8azct86r0h6abbil8mec?autoplay=1


Features
--------

* Status: PIP-Monkey-Patching HACK
